OC.L10N.register(
    "files",
    {
    "Delete" : "తొలగించు",
    "Error" : "పొరపాటు",
    "Name" : "పేరు",
    "Size" : "పరిమాణం",
    "Save" : "భద్రపరచు",
    "Settings" : "అమరికలు",
    "New folder" : "కొత్త సంచయం",
    "Folder" : "సంచయం"
},
"nplurals=2; plural=(n != 1);");
